"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.download = exports.getDownloadUrls = exports.getFunctionsList = exports.setAuth = void 0;
const axios_1 = __importDefault(require("axios"));
const promises_1 = __importDefault(require("fs/promises"));
const googleapis_1 = require("googleapis");
const p_map_1 = __importDefault(require("p-map"));
const path_1 = __importDefault(require("path"));
const clients_1 = require("./clients");
async function setAuth() {
    const auth = new googleapis_1.google.auth.GoogleAuth({
        scopes: ['https://www.googleapis.com/auth/cloud-platform'],
    });
    const authClient = await auth.getClient();
    googleapis_1.google.options({ auth: authClient });
}
exports.setAuth = setAuth;
const getFunctionsList = async (options) => {
    const result = await clients_1.cloudFunctions.projects.locations.functions.list({
        parent: `projects/${options.project}/locations/${options.region}`,
    });
    return result.data.functions;
};
exports.getFunctionsList = getFunctionsList;
const getDownloadUrls = async (functions, options) => {
    const result = await (0, p_map_1.default)(functions, (cFunction) => {
        return Promise.all([
            clients_1.cloudFunctions.projects.locations.functions.generateDownloadUrl({
                name: cFunction.name,
            }),
            cFunction.name.replace(`projects/${options.project}/locations/${options.region}/functions/`, ''),
        ]);
    });
    return result;
};
exports.getDownloadUrls = getDownloadUrls;
const download = async (downloadUrls, options) => {
    for (const [, value] of downloadUrls.entries()) {
        const [functionResult, name] = value;
        const url = functionResult.data.downloadUrl;
        const res = await axios_1.default.get(url, { responseType: 'arraybuffer' });
        await promises_1.default.writeFile(path_1.default.join(options.output, `${name}.zip`), res.data);
    }
};
exports.download = download;
//# sourceMappingURL=helpers.js.map